pywr.parameters.AggregatedIndexParameter — Pywr 0.5dev documentation

# pywr.parameters.AggregatedIndexParameter

class `pywr.parameters.` `AggregatedIndexParameter`

  A collection of IndexParameters

  This class behaves like a set. Parameters can be added or removed from it. Its index is the index of it’s child parameters aggregated using a aggregating function (e.g. sum).

  Parameters: | parameters : iterable of IndexParameter The parameters to aggregate agg_func : callable or str The aggregation function. Must be one of {“sum”, “min”, “max”, “any”, “all”, “product”}, or a callable function which accepts a list of values.

  `__init__`($self, /, *args, **kwargs)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `add` |
  `after` |
  `before` |
  `finish` |
  `get_all_indices` |
  `get_all_values` |
  `get_double_lower_bounds` |
  `get_double_upper_bounds` |
  `get_double_variables` |
  `get_index` |
  `get_integer_lower_bounds` |
  `get_integer_upper_bounds` |
  `get_integer_variables` |
  `get_value` |
  `index` | Returns the current index
  `load` |
  `lower_bounds` |
  `register` |
  `remove` |
  `reset` |
  `set_double_variables` |
  `set_integer_variables` |
  `setup` |
  `unregister` |
  `update` |
  `upper_bounds` |
  `value` | Returns the current index as a float

  Attributes

  `agg_func` |
  `children` |
  `comment` |
  `double_size` |
  `integer_size` |
  `is_variable` |
  `model` |
  `name` |
  `parameters` |
  `parents` |
  `size` |